Championships management — SoL 3 user manual

### Navigation

- index
- next |
- previous |
- User manual »
- User interface »
- Basic entities »

# Championships management

A championship is a set of one or more tourneys, organized by the same club with the same format: all tourneys of a particular championship are obligatorily all singles or all doubles and use the same prize-giving method.

## Menu actions

In addition to the standard actions the menu at the top contains the following items:

Championships management

Tourneys
  Opens the management of the tourneys organized within the selected championship
Download
  Downloads an archive of all the tourneys organized within the selected championship
Ranking
  Creates a PDF document with the ranking of the selected championship

## Insert and edit

Each championship has a description that must be unique within the same club.

Players per team determines the maximum number of players participating as a single competitor: 1 for singles, 2 for doubles, up to 4 for teams.

With skip worst prizes you specify how many worst result will be ignored in the final sum for each player at the end of the season. This is usually used to tolerate that a player could not participate to all the tourneys of the championship and yet she remains competitive.

The coupling method is used as the default value when creating new tourneys within the championship and determines how SoL will couple the participants at each turn (vedi coupling generation method of the tourney for details).

The prize-giving method field determine the method used to assign final prizes. These prizes have two primary scopes:

1. to have uniform, and thus addable, tourney results with the goal of producing the championship ranking
2. by being essentially freely assignable, it becomes possible to swap the position of the first two (or four) players should the final (or semifinal) match between the first and the second (and between the third and fourth) players say so

One particular case is the value `Simple tourneys, no special prizes`, which basically means that the prize-giving will use the competitor’s points as the final prize. This method does not satisfy the first point above, so it’s not a good choice for a championship ranking. These prizes won’t appear in the ranking printout of the tourney, but are considered for its order, and they can be eventually adjusted after the the finals.

The other four values have the following meanings:

`Fixed prizes`
  assigns 18 points to the winner, 16 to the second, 14 to the third, 13 to the fourth and so on down to the 16th place;
`Fixed 40 prizes`
  assigns 1000 points to the winner, 900 to the second, 800 to the third, 750 to the fourth etc, down to 1 point to the 40th place;
`Classic millesimal prizes`
  assigns 1000 points to the winner and a proportional prize to all other players; this is usually preferable when the number of competitors is higher than 20 or so;
`Weighted on previous season`
  similar to the millesimal method, but uses the previous season ranking to assign a weight to the tourney distributing a fraction of that.

The field closed indicates whether the championship is complete: no other tourney can be associated with these championships. The championship lookup combos (for example, when inserting new tourneys) show only those still active.

Previous championship is used by the weighted prize-giving method. It allows the selection of one closed championship.

The responsible is usually the user that inserted that particular championship: the information related to the championship are changeable only by him (and also by the administrator of the system).

### Navigation

- index
- next |
- previous |
- User manual »
- User interface »
- Basic entities »